# Generated by Django 4.1 on 2022-09-19 06:58

from django.conf import settings
from django.core.management import call_command
from django.db import migrations, models
import django.db.models.deletion

import formset.fields


def initialize_opinions(apps, schema_editor):
    OpinionModel = apps.get_model('testapp', 'OpinionModel')
    for counter in range(1, 3000):
        label = f"Opinion {counter:04}"
        OpinionModel.objects.create(tenant=1, label=label)


def initialize_counties(apps, schema_editor):
    call_command('loaddata', settings.BASE_DIR / 'testapp/fixtures/counties.json', verbosity=0)
    CountyUnnormalized = apps.get_model('testapp', 'CountyUnnormalized')
    State = apps.get_model('testapp', 'State')
    County = apps.get_model('testapp', 'County')
    for county in CountyUnnormalized.objects.all():
        state, _ = State.objects.get_or_create(code=county.state_code, name=county.state_name)
        County.objects.create(state=state, name=county.county_name)


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AdvertisementModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', formset.richtext.fields.RichTextField()),
                ('created_by', models.CharField(db_index=True, editable=False, max_length=40)),
            ],
        ),
        migrations.CreateModel(
            name='OpinionModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tenant', models.PositiveSmallIntegerField()),
                ('label', models.CharField(max_length=50, verbose_name='Opinion')),
            ],
            options={
                'unique_together': {('tenant', 'label')},
            },
        ),
        migrations.CreateModel(
            name='PayloadModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data', models.JSONField()),
                ('created_by', models.CharField(db_index=True, editable=False, max_length=40)),
            ],
        ),
        migrations.CreateModel(
            name='PollModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_by', models.CharField(db_index=True, editable=False, max_length=40)),
            ],
        ),
        migrations.CreateModel(
            name='WeightedOpinion',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('weight', models.BigIntegerField(db_index=True, default=0, verbose_name='Weighted Opinion')),
                ('opinion', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='testapp.opinionmodel')),
                ('poll', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='testapp.pollmodel')),
            ],
            options={
                'ordering': ['weight'],
            },
        ),
        migrations.CreateModel(
            name='UserContact',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('phone_number', models.CharField(blank=True, max_length=25, null=True, verbose_name='Phone Number')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='contacts', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.AddField(
            model_name='pollmodel',
            name='weighted_opinions',
            field=formset.fields.SortableManyToManyField(through='testapp.WeightedOpinion', to='testapp.opinionmodel', verbose_name='Weighted Opinions'),
        ),
        migrations.CreateModel(
            name='PersonModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('full_name', models.CharField(max_length=50, verbose_name='Full Name')),
                ('avatar', models.FileField(blank=True, upload_to='images')),
                ('gender', models.CharField(choices=[('female', 'Female'), ('male', 'Male')], default=None, max_length=10, verbose_name='Gender')),
                ('birth_date', models.DateField(verbose_name='Birth Date')),
                ('continent', models.IntegerField(choices=[(1, 'America'), (2, 'Europe'), (3, 'Asia'), (4, 'Africa'), (5, 'Australia'), (6, 'Oceania'), (7, 'Antartica')], verbose_name='Continent')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('created_by', models.CharField(db_index=True, editable=False, max_length=40)),
                ('opinion', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='persons', to='testapp.opinionmodel', verbose_name='Opinion')),
                ('opinions', models.ManyToManyField(related_name='person_groups', to='testapp.opinionmodel', verbose_name='Opinions')),
            ],
        ),
        migrations.CreateModel(
            name='ExtendUser',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('phone_number', models.CharField(blank=True, max_length=25, null=True, verbose_name='Phone Number')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='extend_user', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='CountyUnnormalized',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('state_code', models.CharField(max_length=2, verbose_name='State code')),
                ('state_name', models.CharField(db_index=True, max_length=20, verbose_name='State name')),
                ('county_name', models.CharField(max_length=30, verbose_name='County name')),
            ],
            options={'ordering': ['state_name', 'county_name']},
        ),
        migrations.CreateModel(
            name='State',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('code', models.CharField(max_length=2, verbose_name='Code')),
                ('name', models.CharField(db_index=True, max_length=20, verbose_name='Name')),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='County',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=30, verbose_name='Name')),
                ('state', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='testapp.state')),
            ],
            options={
                'ordering': ['state', 'name'],
            },
        ),
        migrations.RunPython(initialize_opinions, reverse_code=migrations.RunPython.noop),
        migrations.RunPython(initialize_counties, reverse_code=migrations.RunPython.noop),
    ]
